Movie class

Constructors

Movie({required String title, required String genre, required String description, double rating = 0.0})

Properties

description String
getter/setter pair
genre String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rating double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited